@@ -23,7 +23,7 @@ def Create_relvars():
     and then have the corresponding table schemas populated into the Sqlalchemy
     metadata.
     """
-    import relvars
+    from flatland.Database import relvars
     FlatlandDB.Relvars = relvars.define(FlatlandDB)
     FlatlandDB.MetaData.create_all(FlatlandDB.Engine)
 
